@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,9 +11,7 @@
 #include <QUrl>
 
 struct LIBIMPORTWIZARD_EXPORT ldapStruct {
-    ldapStruct()
-    {
-    }
+    ldapStruct() = default;
 
     QUrl ldapUrl;
     QString dn;
