@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ ThunderBirdAddressBook::ThunderBirdAddressBook(const QDir &dir)
 {
 }
 
-ThunderBirdAddressBook::~ThunderBirdAddressBook()
-{
-}
+ThunderBirdAddressBook::~ThunderBirdAddressBook() = default;
 
 void ThunderBirdAddressBook::importAddressBook()
 {
