@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,9 +25,7 @@ ThunderbirdSettings::ThunderbirdSettings(const QString &filename)
 {
 }
 
-ThunderbirdSettings::~ThunderbirdSettings()
-{
-}
+ThunderbirdSettings::~ThunderbirdSettings() = default;
 
 void ThunderbirdSettings::importSettings()
 {
